==> e_commerce-0.0.12-sources.jar: ai/causalfoundry/android/sdk/e_commerce/catalog/CfEComCatalog.kt <==
package ai.causalfoundry.android.sdk.e_commerce.catalog

import ai.causalfoundry.android.sdk.core.CFSetup
import ai.causalfoundry.android.sdk.core.catalog.catalog_models.CatalogSubject
import ai.causalfoundry.android.sdk.core.utils.CoreConstants
import ai.causalfoundry.android.sdk.core.utils.ExceptionManager
import ai.causalfoundry.android.sdk.e_commerce.catalog.catalog_models.BloodCatalogModel
import ai.causalfoundry.android.sdk.e_commerce.catalog.catalog_models.DrugCatalogModel
import ai.causalfoundry.android.sdk.e_commerce.catalog.catalog_models.MedicalEquipmentCatalogModel
import ai.causalfoundry.android.sdk.e_commerce.catalog.catalog_models.OxygenCatalogModel
import ai.causalfoundry.android.sdk.e_commerce.catalog.catalog_models.internal_catalog_models.InternalBloodCatalogModel
import ai.causalfoundry.android.sdk.e_commerce.catalog.catalog_models.internal_catalog_models.InternalDrugModel
import ai.causalfoundry.android.sdk.e_commerce.catalog.catalog_models.internal_catalog_models.InternalMedicalEquipmentCatalogModel
import ai.causalfoundry.android.sdk.e_commerce.catalog.catalog_models.internal_catalog_models.InternalOxygenCatalogModel
import ai.causalfoundry.android.sdk.e_commerce.event_types.ItemType
import ai.causalfoundry.android.sdk.e_commerce.utils.ECommerceConstants
import com.google.gson.Gson

object CfEComCatalog {

    fun callCatalogAPI(itemId : String, itemtype : String, catalogModel : Any) {

        if (itemtype == ItemType.drug.name &&
            catalogModel is DrugCatalogModel
        ) {
            updateDrugCatalog(itemId, catalogModel)
        } else if (itemtype == ItemType.blood.name &&
            catalogModel is BloodCatalogModel
        ) {
            updateBloodCatalog(itemId, catalogModel)
        } else if (itemtype == ItemType.oxygen.name &&
            catalogModel is OxygenCatalogModel
        ) {
            updateOxygenCatalog(itemId, catalogModel)
        } else if (itemtype == ItemType.medical_equipment.name &&
            catalogModel is MedicalEquipmentCatalogModel
        ) {
            updateMedicalEquipmentCatalog(itemId, catalogModel)
        } else {
            ExceptionManager.throwIllegalStateException(
                "Please use correct catalog properties with provided item type"
            )
        }
    }



    //////////////////////////////////////////////////////
    // Drug Catalog
    //////////////////////////////////////////////////////

    fun updateDrugCatalog(drugId: String, drugCatalogModel: String) {
        updateDrugCatalog(
            drugId,
            Gson().fromJson(drugCatalogModel, DrugCatalogModel::class.java)
        )
    }

    fun updateDrugCatalog(drugId: String, drugCatalogModel: DrugCatalogModel) {

        CFSetup().updateCatalogItem(CatalogSubject.drug,
            ECommerceConstants.verifyCatalogForDrug(drugId, drugCatalogModel))

    }


    //////////////////////////////////////////////////////
    // Blood Catalog
    //////////////////////////////////////////////////////

    fun updateBloodCatalog(itemId: String, bloodCatalogModel: String) {
        updateBloodCatalog(
            itemId,
            Gson().fromJson(bloodCatalogModel, BloodCatalogModel::class.java)
        )
    }

    fun updateBloodCatalog(itemId: String, bloodCatalogModel: BloodCatalogModel) {

        CFSetup().updateCatalogItem(CatalogSubject.blood,
            ECommerceConstants.verifyCatalogForBlood(itemId, bloodCatalogModel))

    }


    //////////////////////////////////////////////////////
    // Oxygen Catalog
    //////////////////////////////////////////////////////

    fun updateOxygenCatalog(itemId: String, oxygenCatalogModel: String) {
        updateOxygenCatalog(
            itemId,
            Gson().fromJson(oxygenCatalogModel, OxygenCatalogModel::class.java)
        )
    }

    fun updateOxygenCatalog(itemId: String, oxygenCatalogModel: OxygenCatalogModel) {

        CFSetup().updateCatalogItem(CatalogSubject.oxygen,
            ECommerceConstants.verifyCatalogForOxygen(itemId, oxygenCatalogModel))

    }


    //////////////////////////////////////////////////////
    // Medical Equipment Catalog
    //////////////////////////////////////////////////////

    fun updateMedicalEquipmentCatalog(itemId: String, medicalEquipmentCatalogModel: String) {
        updateMedicalEquipmentCatalog(
            itemId,
            Gson().fromJson(medicalEquipmentCatalogModel, MedicalEquipmentCatalogModel::class.java)
        )
    }

    fun updateMedicalEquipmentCatalog(
        itemId: String,
        medicalEquipmentCatalogModel: MedicalEquipmentCatalogModel
    ) {

        CFSetup().updateCatalogItem(CatalogSubject.medical_equipment,
                ECommerceConstants.verifyCatalogForMedicalEquipment(itemId, medicalEquipmentCatalogModel))

    }


}

==> e_commerce-0.3.2-sources.jar: ai/causalfoundry/android/sdk/e_commerce/catalog/CfEComCatalog.kt <==
package ai.causalfoundry.android.sdk.e_commerce.catalog

import ai.causalfoundry.android.sdk.core.CFSetup
import ai.causalfoundry.android.sdk.core.catalog.catalog_models.CatalogSubject
import ai.causalfoundry.android.sdk.core.utils.ExceptionManager
import ai.causalfoundry.android.sdk.e_commerce.catalog.catalog_models.BloodCatalogModel
import ai.causalfoundry.android.sdk.e_commerce.catalog.catalog_models.DrugCatalogModel
import ai.causalfoundry.android.sdk.e_commerce.catalog.catalog_models.FacilityCatalogModel
import ai.causalfoundry.android.sdk.e_commerce.catalog.catalog_models.GroceryCatalogModel
import ai.causalfoundry.android.sdk.e_commerce.catalog.catalog_models.MedicalEquipmentCatalogModel
import ai.causalfoundry.android.sdk.e_commerce.catalog.catalog_models.OxygenCatalogModel
import ai.causalfoundry.android.sdk.e_commerce.event_types.ItemType
import ai.causalfoundry.android.sdk.e_commerce.utils.ECommerceConstants
import com.google.gson.Gson

object CfEComCatalog {

    fun callCatalogAPI(itemId: String, itemtype: String, catalogModel: Any) {

        val catalogName = "item catalog"

        if (itemtype == ItemType.drug.name &&
            catalogModel is DrugCatalogModel
        ) {
            updateDrugCatalog(itemId, catalogModel)
        } else if (itemtype == ItemType.blood.name &&
            catalogModel is BloodCatalogModel
        ) {
            updateBloodCatalog(itemId, catalogModel)
        } else if (itemtype == ItemType.oxygen.name &&
            catalogModel is OxygenCatalogModel
        ) {
            updateOxygenCatalog(itemId, catalogModel)
        } else if (itemtype == ItemType.medical_equipment.name &&
            catalogModel is MedicalEquipmentCatalogModel
        ) {
            updateMedicalEquipmentCatalog(itemId, catalogModel)
        } else if (itemtype == ItemType.grocery.name &&
            catalogModel is GroceryCatalogModel
        ) {
            updateGroceryCatalog(itemId, catalogModel)
        }else if (itemtype == ItemType.facility.name &&
            catalogModel is FacilityCatalogModel
        ) {
            updateFacilityCatalog(itemId, catalogModel)
        } else {
            ExceptionManager.throwIllegalStateException(
                catalogName,
                "Please use correct catalog properties with provided item type"
            )
        }
    }


    //////////////////////////////////////////////////////
    // Drug Catalog
    //////////////////////////////////////////////////////

    fun updateDrugCatalog(drugId: String, drugCatalogModel: String) {
        updateDrugCatalog(
            drugId,
            Gson().fromJson(drugCatalogModel, DrugCatalogModel::class.java)
        )
    }

    fun updateDrugCatalog(drugId: String, drugCatalogModel: DrugCatalogModel) {

        val drugInternalCatalog = ECommerceConstants.verifyCatalogForDrug(drugId, drugCatalogModel)

        CFSetup().updateCatalogItem(CatalogSubject.drug, drugInternalCatalog)

    }


    //////////////////////////////////////////////////////
    // Grocery Catalog
    //////////////////////////////////////////////////////

    fun updateGroceryCatalog(itemId: String, groceryCatalogModel: String) {
        updateGroceryCatalog(
            itemId,
            Gson().fromJson(groceryCatalogModel, GroceryCatalogModel::class.java)
        )
    }

    fun updateGroceryCatalog(itemId: String, groceryCatalogModel: GroceryCatalogModel) {

        val groceryInternalCatalog =
            ECommerceConstants.verifyCatalogForGrocery(itemId, groceryCatalogModel)

        CFSetup().updateCatalogItem(CatalogSubject.grocery, groceryInternalCatalog)

    }


    //////////////////////////////////////////////////////
    // Blood Catalog
    //////////////////////////////////////////////////////

    fun updateBloodCatalog(itemId: String, bloodCatalogModel: String) {
        updateBloodCatalog(
            itemId,
            Gson().fromJson(bloodCatalogModel, BloodCatalogModel::class.java)
        )
    }

    fun updateBloodCatalog(itemId: String, bloodCatalogModel: BloodCatalogModel) {

        val bloodInternalCatalog =
            ECommerceConstants.verifyCatalogForBlood(itemId, bloodCatalogModel)

        CFSetup().updateCatalogItem(CatalogSubject.blood, bloodInternalCatalog)

    }


    //////////////////////////////////////////////////////
    // Oxygen Catalog
    //////////////////////////////////////////////////////

    fun updateOxygenCatalog(itemId: String, oxygenCatalogModel: String) {
        updateOxygenCatalog(
            itemId,
            Gson().fromJson(oxygenCatalogModel, OxygenCatalogModel::class.java)
        )
    }

    fun updateOxygenCatalog(itemId: String, oxygenCatalogModel: OxygenCatalogModel) {

        val oxygenInternalCatalog =
            ECommerceConstants.verifyCatalogForOxygen(itemId, oxygenCatalogModel)

        CFSetup().updateCatalogItem(CatalogSubject.oxygen, oxygenInternalCatalog)

    }


    //////////////////////////////////////////////////////
    // Medical Equipment Catalog
    //////////////////////////////////////////////////////

    fun updateMedicalEquipmentCatalog(itemId: String, medicalEquipmentCatalogModel: String) {
        updateMedicalEquipmentCatalog(
            itemId,
            Gson().fromJson(medicalEquipmentCatalogModel, MedicalEquipmentCatalogModel::class.java)
        )
    }

    fun updateMedicalEquipmentCatalog(
        itemId: String,
        medicalEquipmentCatalogModel: MedicalEquipmentCatalogModel
    ) {

        val medicalInternalCatalog = ECommerceConstants.verifyCatalogForMedicalEquipment(
            itemId,
            medicalEquipmentCatalogModel
        )

        CFSetup().updateCatalogItem(CatalogSubject.medical_equipment, medicalInternalCatalog)

    }

    //////////////////////////////////////////////////////
    // Facility Catalog
    //////////////////////////////////////////////////////

    fun updateFacilityCatalog(facilityId: String, facilityCatalogModel: String) {
        updateFacilityCatalog(
            facilityId,
            Gson().fromJson(facilityCatalogModel, FacilityCatalogModel::class.java)
        )
    }

    fun updateFacilityCatalog(
        facilityId: String,
        facilityCatalogModel: FacilityCatalogModel
    ) {

        val facilityInternalCatalog = ECommerceConstants.verifyCatalogForFacility(
            facilityId,
            facilityCatalogModel
        )

        CFSetup().updateCatalogItem(CatalogSubject.facility, facilityInternalCatalog)

    }


}
